@@ -1,6 +1,6 @@
 import pytest
-import stribor as st
 import torch
+import stribor as st
 
 @pytest.mark.parametrize('input_dim', [(10, 2), (2, 10), (1, 10, 2), (5, 10, 2)])
 @pytest.mark.parametrize('natural_ordering', [True, False])
@@ -10,10 +10,14 @@ def test_made_zero_trace(input_dim, natural_ordering, reverse_ordering, return_p
     torch.manual_seed(123)
 
     dim = input_dim[-1]
-    model = st.net.MADE(dim, [64, 64], dim * 8,
-                        natural_ordering=natural_ordering,
-                        reverse_ordering=reverse_ordering,
-                        return_per_dim=return_per_dim)
+    model = st.net.MADE(
+        in_dim=dim,
+        hidden_dims=[64, 64],
+        out_dim=dim * 8,
+        natural_ordering=natural_ordering,
+        reverse_ordering=reverse_ordering,
+        return_per_dim=return_per_dim
+    )
 
     x = torch.randn(*input_dim).requires_grad_(True)
 
